@@ -6,6 +6,7 @@ use Class::Accessor::Lite
         name
         primary_keys
         columns
+        escaped_columns
         sql_types
         row_class
     ) ]
@@ -16,6 +17,9 @@ use Class::Load ();
 sub new {
     my ($class, %args) = @_;
     my $self = bless {
+        deflators       => [],
+        inflators       => [],
+        escaped_columns => {},
         %args
     }, $class;
 
@@ -28,7 +32,7 @@ sub new {
     for my $col (@{$self->columns}) {
         no strict 'refs';
         unless ($row_class->can($col)) {
-            *{"$row_class\::$col"} = $row_class->_lazy_get_data($col);
+            *{"$row_class\::$col"} = $row_class->generate_column_accessor($col);
         }
     }
     $self->row_class($row_class);
@@ -93,6 +97,25 @@ sub call_inflate {
     return $col_value;
 }
 
+sub has_deflators {
+    my $self = shift;
+    return scalar @{ $self->{deflators} };
+}
+
+sub has_inflators {
+    my $self = shift;
+    return scalar @{ $self->{inflators} };
+}
+
+sub prepare_from_dbh {
+    my ($self, $dbh) = @_;
+
+    $self->escaped_columns->{$dbh->{Driver}->{Name}} ||= [
+        map { \$dbh->quote_identifier($_) }
+        @{$self->columns}
+    ];
+}
+
 1;
 
 __END__
@@ -137,4 +160,12 @@ execute deflate.
 
 execute inflate.
 
+=item $table->has_deflators()
+
+Returns true if there are any deflators
+
+=item $table->has_inflators();
+
+Returns true if there are any inflators
+
 =back
